@@ -1,18 +1,19 @@
 from html import escape
-from typing import Any
+from typing import Any, TYPE_CHECKING
 from ..errors import RenderError
-from .transformers import TRANSFORMERS
+
+if TYPE_CHECKING:
+    from ..context import Context
 
 
-def transform_props(props: dict[str, Any]):
+def transform_props(props: dict[str, Any], *, context: "Context"):
     props_copy = props.copy()
 
-    for matcher, transformer in TRANSFORMERS:
+    for matcher, transformer in context._prop_transformers:
         if isinstance(matcher, str):
             key = matcher
             if key in props_copy:
                 value = props_copy[key]
-                props_copy[key] = None
                 if callable(transformer):
                     transformer(key, value, props_copy)
                 else:
@@ -21,13 +22,16 @@ def transform_props(props: dict[str, Any]):
             for key, value in list(props_copy.items()):
                 if matcher(key, value):
                     transformer(key, value, props_copy)
-                    props_copy[key] = None
         else:
             raise RenderError(
                 f"Invalid matcher: {matcher} must be a callable or a string."
             )
 
-    return props_copy
+    return {
+        key: value
+        for key, value in props_copy.items()
+        if value is not None
+    }
 
 
 def render_props(props: dict[str, Any]) -> str:
