@@ -1,14 +1,15 @@
 from typing import Generic, TypeVar, Unpack, TYPE_CHECKING
+from ..extra.transformers import transformer_for
 
 if TYPE_CHECKING:
-    from seamless.types.styling.css_properties import CSSProperties
+    from ..types.styling.css_properties import CSSProperties
 
 T = TypeVar("T")
 
 
-class Style:
+class StyleObject:
     class _StyleProperty(Generic[T]):
-        def __init__(self, instance: "Style", name: str):
+        def __init__(self, instance: "StyleObject", name: str):
             self.instance = instance
             self.name = name.replace("_", "-")
 
@@ -16,10 +17,12 @@ class Style:
             self.instance.style[self.name] = value
             return self.instance
 
-    def __init__(self, *styles: "Style | dict", **kwargs: Unpack["CSSProperties"]):
+    def __init__(
+        self, *styles: "StyleObject | CSSProperties", **kwargs: Unpack["CSSProperties"]
+    ):
         self.style: dict[str, object] = {}
         for style in styles:
-            if isinstance(style, Style):
+            if isinstance(style, StyleObject):
                 style = style.style
             self.style.update(style)
         self.style.update(kwargs)
@@ -28,7 +31,7 @@ class Style:
         }
 
     def copy(self):
-        return Style(self)
+        return StyleObject(self)
 
     def to_css(self):
         return "".join(map(lambda x: f"{x[0]}:{x[1]};", self.style.items()))
@@ -37,4 +40,9 @@ class Style:
         return self.to_css()
 
     def __getattr__(self, name: str):
-        return Style._StyleProperty(self, name)
\ No newline at end of file
+        return StyleObject._StyleProperty(self, name)
+
+
+@transformer_for(lambda _, value: isinstance(value, StyleObject))
+def style_transformer(key, value: StyleObject, props):
+    props[key] = value.to_css()
